@@ -17,15 +17,17 @@
  *
  */
 
-#include "grantleeki18nlocalizer_p.h"
+#include "grantleeki18nlocalizer.h"
 #include "grantleetheme_debug.h"
 
 #include <QLocale>
 #include <QDate>
+#include <QDebug>
 
 #include <grantlee/safestring.h>
 
 #include <KLocalizedString>
+using namespace GrantleeTheme;
 
 GrantleeKi18nLocalizer::GrantleeKi18nLocalizer()
     : Grantlee::QtLocalizer()
@@ -76,7 +78,9 @@ QString GrantleeKi18nLocalizer::processArguments(const KLocalizedString &kstr,
     }
 
     // Return localized in the currenctly active locale
-    return str.toString({ currentLocale() });
+    const QString translatedStr = str.toString(mApplicationDomain.isEmpty() ? str.applicationDomain().constData() : mApplicationDomain.constData());
+    //qDebug() << " translatedStr"<< translatedStr << " domain :" << str.applicationDomain() << " currentLocale() "<< currentLocale() << " Specific applicationDomain" << mApplicationDomain;
+    return translatedStr;
 }
 
 QString GrantleeKi18nLocalizer::localizeContextString(const QString &string, const QString &context, const QVariantList &arguments) const
@@ -109,3 +113,18 @@ QString GrantleeKi18nLocalizer::localizeMonetaryValue(qreal value, const QString
 {
     return QLocale(currentLocale()).toCurrencyString(value, currencySymbol);
 }
+
+QString GrantleeKi18nLocalizer::currentLocale() const
+{
+    QString locale = Grantlee::QtLocalizer::currentLocale();
+    const int f = locale.indexOf(QLatin1Char('_'));
+    if (f >= 0) {
+        locale.truncate(f);
+    }
+    return locale;
+}
+
+void GrantleeKi18nLocalizer::setApplicationDomain(const QByteArray &domain)
+{
+    mApplicationDomain = domain;
+}
